@@ -1,8 +1,7 @@
 /* exported AccountsMonitor */
 
-const { Gio, GObject, Polari } = imports.gi;
+const { Gio, GObject, Polari, TelepathyGLib: Tp } = imports.gi;
 const Signals = imports.signals;
-const Tp = imports.gi.TelepathyGLib;
 
 var AccountsMonitor = class {
     static getDefault() {
@@ -55,7 +54,7 @@ var AccountsMonitor = class {
         if (settings)
             return settings;
 
-        let path = '/org/gnome/Polari/Accounts/%s/'.format(account.get_path_suffix());
+        let path = `/org/gnome/Polari/Accounts/${account.get_path_suffix()}/`;
         settings = new Gio.Settings({ schema_id: 'org.gnome.Polari.Account',
                                       path: path });
         this._accountSettings.set(accountPath, settings);
