@@ -1,12 +1,13 @@
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported MessageNotification UndoNotification NotificationQueue
+            SimpleOutput GridOutput CommandOutputQueue */
+
+const { GObject, Gtk, Pango } = imports.gi;
 const Mainloop = imports.mainloop;
-const Pango = imports.gi.Pango;
 
 const TIMEOUT = 7;
 const COMMAND_OUTPUT_REVEAL_TIME = 3;
 
-var AppNotification = GObject.registerClass(
+const AppNotification = GObject.registerClass(
 class AppNotification extends Gtk.Revealer {
     _init() {
         if (this.constructor.name == 'AppNotification')
@@ -89,7 +90,7 @@ var UndoNotification = GObject.registerClass({
     }
 });
 
-var CommandOutputNotification = GObject.registerClass(
+const CommandOutputNotification = GObject.registerClass(
 class CommandOutputNotification extends AppNotification {
     _init() {
         if (this.constructor.name == 'CommandOutputNotification')
@@ -139,7 +140,7 @@ class GridOutput extends CommandOutputNotification {
                     continue;
                 let w = new Gtk.Label({ label: item });
                 grid.attach(w, j, row, 1, 1);
-             }
+            }
             row++;
         }
         this.add(grid);
@@ -170,7 +171,7 @@ class NotificationQueue extends Gtk.Frame {
 
     _onChildDestroy() {
         if (this._grid.get_children().length == 0)
-           this.hide();
+            this.hide();
     }
 });
 
