@@ -19,7 +19,7 @@ const MAX_RETRIES = 3;
 
 const IRC_SCHEMA_REGEX = /^(irc?:\/\/)([\da-z.-]+):?(\d+)?\/(?:%23)?([\w.+-]+)/i;
 
-const AUTOSTART_DIR = `${GLib.get_user_config_dir()}/autostart`;
+const AUTOSTART_DIR = `${GLib.get_user_config_dir()}${'/'}autostart`;
 const AUTOSTART_FILE = '/org.gnome.Polari.Autostart.desktop';
 
 var Application = GObject.registerClass({
@@ -285,8 +285,26 @@ var Application = GObject.registerClass({
         this._userStatusMonitor = UserStatusMonitor.getDefault();
         this._networksManager = NetworksManager.getDefault();
 
-        if (!Gio.NetworkMonitor.get_default().get_network_metered())
-            this._serverRoomManager = ServerRoomManager.getDefault();
+        // The portal implementation fetches the initial state asynchronously,
+        // so track when the it becomes valid to not base decisions on an
+        // incorrect offline state
+        let networkMonitor = Gio.NetworkMonitor.get_default();
+        networkMonitor.state_valid =
+            !Utils.isFlatpakSandbox() &&
+            GLib.getenv('GTK_USE_PORTAL') != '1';
+
+        if (!networkMonitor.state_valid) {
+            let id = networkMonitor.connect('network-changed', () => {
+                networkMonitor.disconnect(id);
+                networkMonitor.state_valid = true;
+
+                if (!networkMonitor.network_metered)
+                    this._serverRoomManager = ServerRoomManager.getDefault();
+            });
+        } else {
+            if (!networkMonitor.network_metered)
+                this._serverRoomManager = ServerRoomManager.getDefault();
+        }
 
         this._accountsMonitor.connect('account-status-changed',
                                       this._onAccountStatusChanged.bind(this));
@@ -802,7 +820,8 @@ var Application = GObject.registerClass({
                 'Rares Visalom <rares.visalom@gmail.com>',
                 'Danny Mølgaard <moelgaard.dmp@gmail.com>',
                 'Justyn Temme <Justyntemme@gmail.com>',
-                'unkemptArc99 <abhishekbhardwaj540@gmail.com>'
+                'unkemptArc99 <abhishekbhardwaj540@gmail.com>',
+                'Oscar Shrimpton <oscar.shrimpton.personal@gmail.com>'
             ],
             artists: [
                 'Sam Hewitt <hewittsamuel@gmail.com>',
