@@ -1,8 +1,9 @@
 /* exported ChatEntry EntryArea NickPopover */
 
-const { Gdk, GdkPixbuf, Gio, GLib, GObject, Gspell, Gtk } = imports.gi;
+const {
+    Gdk, GdkPixbuf, Gio, GLib, GObject, Gspell, Gtk, TelepathyGLib: Tp
+} = imports.gi;
 const Mainloop = imports.mainloop;
-const Tp = imports.gi.TelepathyGLib;
 
 const ChatView = imports.chatView;
 const { DropTargetIface } = imports.pasteManager;
@@ -418,8 +419,9 @@ var EntryArea = GObject.registerClass({
             });
         } catch (e) {
             let type = typeof this._pasteContent;
-            debug('Failed to paste content of type ' +
-                  (type == 'object' ? this._pasteContent.toString() : type));
+            if (type == 'object')
+                type = this._pasteContent.toString();
+            debug(`Failed to paste content of type ${type}`);
         }
         this._confirmLabel.hide();
     }
