@@ -1,8 +1,7 @@
 /* exported IrcParser */
 
-const { Gio, GLib } = imports.gi;
+const { Gio, GLib, TelepathyGLib: Tp } = imports.gi;
 const Signals = imports.signals;
-const Tp = imports.gi.TelepathyGLib;
 
 const AppNotifications = imports.appNotifications;
 const { RoomManager } = imports.roomManager;
@@ -104,7 +103,7 @@ var IrcParser = class {
                         try {
                             contact = c.dup_contact_by_id_finish(res);
                         } catch (e) {
-                            logError(e, 'Failed to get contact for ' + nick);
+                            logError(e, `Failed to get contact for ${nick}`);
                             return;
                         }
                         this._room.add_member(contact);
@@ -120,7 +119,7 @@ var IrcParser = class {
                     break;
                 }
                 if (argv.length)
-                    log('Excess arguments to JOIN command: ' + argv);
+                    log(`Excess arguments to JOIN command: ${argv}`);
 
                 let account = this._room.account;
                 let app = Gio.Application.get_default();
@@ -144,7 +143,7 @@ var IrcParser = class {
                         try {
                             contact = c.dup_contact_by_id_finish(res);
                         } catch (e) {
-                            logError(e, 'Failed to get contact for ' + nick);
+                            logError(e, `Failed to get contact for ${nick}`);
                             return;
                         }
                         this._room.remove_member(contact);
@@ -198,7 +197,7 @@ var IrcParser = class {
                     break;
                 }
                 if (argv.length)
-                    log('Excess arguments to NICK command: ' + argv);
+                    log(`Excess arguments to NICK command: ${argv}`);
 
                 this._app.setAccountNick(this._room.account, nick);
                 break;
