@@ -1,8 +1,7 @@
 /* exported RoomManager */
 
-const { Gio, GLib, Polari } = imports.gi;
+const { Gio, GLib, Polari, TelepathyGLib: Tp } = imports.gi;
 const Signals = imports.signals;
-const Tp = imports.gi.TelepathyGLib;
 
 const { AccountsMonitor } = imports.accountsMonitor;
 
