@@ -1,9 +1,8 @@
 /* exported ServerRoomManager ServerRoomList */
 
-const { Gdk, GLib, GObject, Gtk } = imports.gi;
+const { Gdk, GLib, GObject, Gtk, TelepathyGLib: Tp } = imports.gi;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
-const Tp = imports.gi.TelepathyGLib;
 
 const { AccountsMonitor } = imports.accountsMonitor;
 const { RoomManager } = imports.roomManager;
@@ -328,7 +327,7 @@ var ServerRoomList = GObject.registerClass({
                 let room = roomManager.lookupRoomByName(roomInfo.get_name(), this._account);
                 let sensitive = room == null;
                 let checked = !sensitive;
-                let count = '%d'.format(roomInfo.get_members_count(null));
+                let count = `${roomInfo.get_members_count(null)}`;
 
                 let { CHECKED, NAME, COUNT, SENSITIVE } = RoomListColumn;
                 let iter = store.insert_with_valuesv(-1,
